@@ -199,18 +199,18 @@ def get_call_schedule(call_prices: List[CallabilityPrice]):
 
 
 def get_qlcallablebond(bond_info: FixedRateBond,
-                        bond_setting: BondSetting,
                         bond_schedule: ql.QuantLib.Schedule,
                         coupons: List[float],
                         call_schedule: ql.QuantLib.CallabilitySchedule,
                         settlement_days: int = 0):
+    print(bond_info.settings.day_count)
     callbond = ql.CallableFixedRateBond(
                 settlement_days, 
                 bond_info.face_value,
                 bond_schedule, 
                 coupons, 
-                ql_day_count[bond_setting.day_count],
-                ql_business_day[bond_setting.business_day], 
+                ql_day_count[bond_info.settings.day_count],
+                ql_business_day[bond_info.settings.business_day], 
                 bond_info.face_value, 
                 datestr_to_qldate(bond_info.issue_date),
                 call_schedule)
@@ -242,30 +242,30 @@ def callbond_stats(value_date: str,
     
     oas = ql_callbond.OAS(clean_price, 
                         curve_handle,
-                        ql_day_count[call_class.setting.day_count],
+                        ql_day_count[call_class.info.settings.day_count],
                         ql.Compounded,
-                        ql_frequency[call_class.setting.frequency],
+                        ql_frequency[call_class.info.settings.frequency],
                         vdate) * 100
     call_risks["OAS"] =  oas
     bond_yield  = ql_callbond.bondYield(clean_price,
-                        ql_day_count[call_class.setting.day_count],
+                        ql_day_count[call_class.info.settings.day_count],
                         ql.Compounded,
-                        ql_frequency[call_class.setting.frequency],
+                        ql_frequency[call_class.info.settings.frequency],
                         vdate) * 100
     call_risks["Yield"] = bond_yield
 
     e_convex = ql_callbond.effectiveConvexity(oas/100, 
                                 curve_handle,
-                                ql_day_count[call_class.setting.day_count],
+                                ql_day_count[call_class.info.settings.day_count],
                                 ql.Compounded,
-                                ql_frequency[call_class.setting.frequency])
+                                ql_frequency[call_class.info.settings.frequency])
     call_risks["Effective Convexity"] = e_convex
 
     e_duration = ql_callbond.effectiveConvexity(oas/100, 
                                 curve_handle,
-                                ql_day_count[call_class.setting.day_count],
+                                ql_day_count[call_class.info.settings.day_count],
                                 ql.Compounded,
-                                ql_frequency[call_class.setting.frequency])
+                                ql_frequency[call_class.info.settings.frequency])
     call_risks["Effective Duration"] = e_duration
     
     #Calculate Yield To Call
@@ -276,14 +276,13 @@ def callbond_stats(value_date: str,
 def qlCallableBond_from_Class(call_class: CallableBondParam,
                             qlcalendar):
     qlschedule = qlSchedule_from_Model(call_class.info,
-                                        call_class.setting, qlcalendar) 
+                                        call_class.info.settings, qlcalendar) 
     structure = structure_from_qlSchedule(call_class.info,
-                                            call_class.setting,
+                                            call_class.info.settings,
                                             qlschedule)
     call_class.structure = structure
     qlcall_schedule = qlCallabilitySchedule_from_class(call_class.call_structure)
-    qlcallbond = get_qlcallablebond(call_class.info,
-                                    call_class.setting, 
+    qlcallbond = get_qlcallablebond(call_class.info, 
                                     qlschedule, 
                                     [call_class.info.coupon/100], 
                                     qlcall_schedule )
