@@ -156,8 +156,8 @@ def calc_equiv_rate(from_date: str,
 
     
 def ql_spread_handle(value_date: str, 
-                    t_structure, 
-                    spreads: List[Rate],
+                    t_structure: ql.QuantLib.YieldTermStructure, 
+                    spreads: Optional[List[Rate]] = None,
                     calendar = None):
     vdate = datestr_to_qldate(value_date)
     ts_handle = ql.YieldTermStructureHandle(t_structure)
@@ -170,26 +170,54 @@ def ql_spread_handle(value_date: str,
     spread_handles = []
     spread_dates = []
     spread_quotes = []
+    handle = None
+    if spreads:
+        for spread in spreads:
+            spread_quote = ql.SimpleQuote(spread.rate/100)
+            spread_quotes.append(spread_quote)
+            spread_handle = ql.QuoteHandle(spread_quote)
+            spread_handles.append(spread_handle)
+            maturity = qlcalendar.advance(vdate, get_qlPeriod(spread.tenor))
+            spread_dates.append(maturity)
 
-    for spread in spreads:
-        spread_quote = ql.SimpleQuote(spread.rate/100)
-        spread_quotes.append(spread_quote)
-        spread_handle = ql.QuoteHandle(spread_quote)
-        spread_handles.append(spread_handle)
-        maturity = qlcalendar.advance(vdate, get_qlPeriod(spread.tenor))
-        spread_dates.append(maturity)
-
-    spread_curve = ql.SpreadedLinearZeroInterpolatedTermStructure(
-                            ts_handle,
-                            spread_handles,
-                            spread_dates)
-    spread_curve_handle = ql.YieldTermStructureHandle(spread_curve)
-
-    return spread_curve_handle
+        spread_curve = ql.SpreadedLinearZeroInterpolatedTermStructure(
+                                ts_handle,
+                                spread_handles,
+                                spread_dates)
+        handle = ql.YieldTermStructureHandle(spread_curve)
+    else:
+        handle = ql.YieldTermStructureHandle
     
 
+    return t_structure
+    
+
+def qlFlatForward(flatforward: FlatForwardCurve):
+    qlDate = datestr_to_qldate(flatforward.date)
+    qlHandle = ql.QuoteHandle(ql.SimpleQuote(flatforward.rate/100))
+    qlDayCounter = ql_day_count[flatforward.day_count]
+    qlCompounding = ql_compounding[flatforward.compounding]
+    qlFrequency = ql_frequency[flatforward.frequency]
+    
+    return ql.FlatForward(qlDate, qlHandle, qlDayCounter, qlCompounding, qlFrequency)
 
 
+def qlPiecewise(pwc: PiecewiseCurve, cal = None):
+    return curve_piecewise(pwc.value_date, 
+                            pwc.depo_setting, 
+                            pwc.depo_rates, 
+                            pwc.par_setting, 
+                            pwc.par_rates,
+                            cal = cal)
 
 
+def qlYtsHandle(value_date: str, 
+                t_structure: ql.QuantLib.YieldTermStructure, 
+                spreads: Optional[List[Rate]] = None,
+                calendar = None):
+    return ql_spread_handle(value_date, 
+                    t_structure, 
+                    spreads,
+                    calendar = calendar)
+
 
